@@ -1,16 +1,12 @@
 my $repo = "https://qgvdial.googlecode.com/svn/trunk";
-my $nsis = "\"C:\\Program Files (x86)\\NSIS\\makensis.exe\"";
+my $wixbase='C:/Program Files (x86)/Windows Installer XML v3/bin';
 my $cmd;
 my $line;
 
 # Delete any existing version file
-if (-f ver.cfg)
-{
-    unlink(ver.cfg);
-}
+if (-f ver.cfg) { unlink(ver.cfg); }
 # Get the latest version file from the repository
-$cmd = "svn export $repo/build-files/ver.cfg";
-system($cmd);
+system("svn export $repo/build-files/ver.cfg");
 
 # Pull out the version from the file
 open(QVARFILE, "ver.cfg") or die;
@@ -31,19 +27,23 @@ $svnver = $1;
 $qver = "$qver.$svnver";
 
 system("powershell Remove-Item -Recurse -Force qgvdial*");
-$cmd = "svn export $repo qgvdial-$qver";
-system($cmd);
+system("svn export $repo qgvdial-$qver");
 system("copy qgvdial-$qver\\icons\\Google.png qgvdial-$qver\\src\\qgvdial.png");
+system("move qgvdial-$qver\\build-files\\qt.conf.win qgvdial-$qver\\build-files\\qt.conf");
 
-$cmd = "cd qgvdial-$qver/src & perl ../build-files/version.pl __QGVDIAL_VERSION__ $qver";
+system("cd qgvdial-$qver & perl build-files/version.pl __QGVDIAL_VERSION__ $qver");
+$cmd = `echo %QTDIR%`;
+$cmd =~ s/\\/\\\\/g;
+$cmd = "cd qgvdial-$qver & perl build-files/version.pl __QTDIR__ $cmd";
 system($cmd);
 
-# Do everything upto the preparation of the debian directory. Code is still not compiled.
-$cmd = "cd qgvdial-$qver & qmake & make all";
+# Compile it!
+$cmd = "cd qgvdial-$qver & qmake & make release";
 system($cmd);
 
 $cmd = "copy qgvdial-$qver\\src\\release\\qgvdial.exe I:\\Uv\\releases\\qgvdial\\win-install\\qgvdial\\bin";
 system($cmd);
 
-$cmd = "$nsis qgvdial-$qver\\src\\setup.nsi";
-system($cmd);
+# New setup: Create MSI.
+system("cd qgvdial-$qver/build-files & \"$wixbase/candle.exe\" qgvdial.wxs");
+system("cd qgvdial-$qver/build-files & \"$wixbase/light.exe\" -cultures:en-US -ext WixUIExtension qgvdial.wixobj -o ..\\qgvdial-$qver.msi");
