@@ -137,15 +137,18 @@ private:
     int                     nCurrent;
 
     //! We use this to check if we're online
-    QNetworkConfigurationManager nwCfg;
+    QNetworkConfigurationManager *nwCfg;
 
     //! Timeout timer for web page loading
-    QTimer                      pageTimeoutTimer;
-    QNetworkReply              *pCurrentReply;
+    QTimer                  pageTimeoutTimer;
+    QNetworkReply          *pCurrentReply;
 
     //! This flag is to be set to distinguish between call out and call back.
     bool                    bIsCallback;
 
+    //! This flag mentions if we are in cancellation
+    bool                    bInDialCancel;
+
     friend class Singletons;
 };
 
